@@ -10,9 +10,8 @@
 
 #include "globals.h"
 
-#define VERSION "asp2php 0.75.13 - March 1, 2001\n" \
-    "Copyright 2001 By Michael Kohn (naken@naken.cc)\n" \
-    "License: GPL\n"
+#define VERSION "asp2php 0.75.14 - May 7, 2001\n" \
+    "Copyright 2001 By Michael Kohn (naken@naken.cc)\n"
 #include "functions.h"
 
 /* ASP to PHP converter           */
@@ -553,6 +552,8 @@ char temptoken[TOKENSIZE];
 char newtoken[1024];
 int t,ch;
 
+printf("in eval token: %s\n",token);
+
   if (strcasecmp(token,"exit")==0)
   { 
     if (loopcount==0)
@@ -699,6 +700,21 @@ int t,ch;
         else
       { ch=getc(in); }
       if (ch==EOF) break;
+
+      if (ch=='%')
+      {
+        ch=getc(in);
+        if (ch=='>')
+        {
+          putc('?',out);
+          putc('>',out);
+          copyhtml();
+          return 0;
+        }
+          else
+        { putc('%',out);}
+      }
+
       putc(ch,out);
     }
     line++;
@@ -788,6 +804,8 @@ char token[TOKENSIZE];
 char newtoken[LINELENGTH];
 int tokentype,c,ch;
 
+printf("in parse_body: %s\n",token);
+
   while((tokentype=gettoken(token))!=0)
   {
     if (tokentype==5 && iflag==1)
@@ -895,6 +913,21 @@ int tokentype,c,ch;
           else
         { ch=getc(in); }
         if (ch==EOF) break;
+
+        if (ch=='%')
+        {
+          ch=getc(in);
+          if (ch=='>')
+          {
+            putc('?',out);
+            putc('>',out);
+            copyhtml();
+            return 0;
+          }
+            else
+          { putc('%',out);}
+        }
+
         putc(ch,out);
       }
       line++;
@@ -1113,18 +1146,6 @@ int t;
         }
 
         convert(filename_asp,filename_php);
-
-/*
-        if (pngs==1)
-	{ sprintf(newdir,"unipiss \"%s\" \"%s\"",filename_asp,filename_php); }
-	  else
-	{ sprintf(newdir,"cp \"%s\" \"%s\"",filename_asp,filename_php); }
-        if (system(newdir)!=0)
-	{
-          printf("Error: Couldn't copy file: %s\n\n",filename_asp);
-	  return 1;
-	}
-*/
       }
         else
       {
