@@ -153,6 +153,8 @@ void parse_include(char *tag)
 {
 char value[100];
 
+  change_tag(tag);
+
   if (getattribute(tag,"file",value)==1)
   {
     fprintf(out,"? require(\"%s\"); ?>",value);
@@ -214,6 +216,13 @@ int tagptr,ch;
       {
         parse_include(tag);
         return 0; 
+      }
+         else
+      if (strncasecmp(tag,"!--#include",11)==0)
+      {
+        change_tag(tag);
+        fprintf(out,"%s",tag);
+        return 0; 
       }
         else
       if (strncasecmp(tag,"img",3)==0)
